StencilFamily

Struct StencilFamily 

pub struct StencilFamily<const IN: usize, const OUT: usize, const MAX_REGS: usize, const HOLES: usize, const JUMPS: usize> {
    pub relocation_data: &'static [Relocation],
    pub stencils: &'static [Stencil<IN, OUT, HOLES, JUMPS>],
}
Describes the way to pass a variable in and out of a stencil

Fields

relocation_data: &'static [Relocation]

Pool of stencil relocation data, possibly shared by multiple stencils

The relocation data for each stencil is sorted by relocation offset.

stencils: &'static [Stencil<IN, OUT, HOLES, JUMPS>]

Implementations

Source

impl<const IN: usize, const OUT: usize, const MAX_REGS: usize, const HOLES: usize, const JUMPS: usize> StencilFamily<IN, OUT, MAX_REGS, HOLES, JUMPS>

pub fn inputs(&self) -> usize

pub fn outputs(&self) -> usize

pub fn max_regs(&self) -> usize

pub fn holes(&self) -> usize

pub fn jumps(&self) -> usize

pub fn select( &self, inputs: &[Location; IN], outputs: &[Location; OUT], holes: &[usize; HOLES], ) -> Option<SelectedStencil<IN, OUT, HOLES, JUMPS>>