pub struct StencilLibrary<const MAX_REGS: usize> {
pub code: &'static [u8],
pub empty: &'static [u8],
pub moves: &'static StencilFamily<1, 1, MAX_REGS, 0, 1>,
}Expand description
A library of stencils
Fields
code: &'static [u8]All the stencil binary code, referred to by stencils
empty: &'static [u8]The code for an empty stencil, used to prune consecutive jumps
moves: &'static StencilFamily<1, 1, MAX_REGS, 0, 1>Stencils to move values between registers/the stack