StencilStack

Trait StencilStack 

pub trait StencilStack {
    // Required methods
    fn get(&self, i: usize) -> usize;
    fn set(&mut self, i: usize, v: usize);
}
A trait for a stencil stack

The compiler will generate code that uses stacks when a variable is determined to be “spilled”.

Requirements

Note that the functions must be annotated with #[inline] and must not involve further linkage. patchouly-build will report these violations on build-time.

Required Methods

fn get(&self, i: usize) -> usize

fn set(&mut self, i: usize, v: usize)

Implementors