Relocation

Struct Relocation 

pub struct Relocation(/* private fields */);
A relocation entry

It roughly follows the Relocation struct from the object crate, with some simplifications. Represents a bitfield.

Implementations

Source

impl Relocation

pub const OFFSET_BITS: u32 = 16u32

The number of bits offset occupies in the bitfield.

pub const OFFSET_OFFSET: u32 = 0u32

The bitfield start bit of offset.

pub const ENCODING_BITS: u32 = 7u32

The number of bits encoding occupies in the bitfield.

pub const ENCODING_OFFSET: u32 = 16u32

The bitfield start bit of encoding.

pub const RELATIVE_BITS: u32 = 1u32

The number of bits relative occupies in the bitfield.

pub const RELATIVE_OFFSET: u32 = 23u32

The bitfield start bit of relative.

pub const SIZE_BITS: u32 = 8u32

The number of bits size occupies in the bitfield.

pub const SIZE_OFFSET: u32 = 24u32

The bitfield start bit of size.

pub const ADDEND_BITS: u32 = 12u32

The number of bits addend occupies in the bitfield.

pub const ADDEND_OFFSET: u32 = 32u32

The bitfield start bit of addend.

pub const PATCH_KIND_BITS: u32 = 4u32

The number of bits patch_kind occupies in the bitfield.

pub const PATCH_KIND_OFFSET: u32 = 44u32

The bitfield start bit of patch_kind.

pub const PATCH_ID_BITS: u32 = 16u32

The number of bits patch_id occupies in the bitfield.

pub const PATCH_ID_OFFSET: u32 = 48u32

The bitfield start bit of patch_id.

pub const fn new() -> Self

Creates a new bitfield instance.

pub const fn new_without_defaults() -> Self

Creates a new bitfield instance without setting any default values.

pub const fn from_bits(bits: u64) -> Self

Creates a new bitfield instance from the given bits.

pub const fn from_bits_with_defaults(bits: u64) -> Self

Creates a new bitfield instance from the given bits while respecting field default values.

pub const fn into_bits(self) -> u64

Returns the bits of the bitfield.

pub const fn offset(&self) -> u16

Returns bits 0..=15.

pub const fn encoding(&self) -> RelocationEncoding

Returns bits 16..=22.

pub const fn relative(&self) -> bool

Returns bit 23.

pub const fn size(&self) -> u8

Returns bits 24..=31.

pub const fn addend(&self) -> i16

Returns sign-extended bits 32..=43 from the sign-bit 32.

pub const fn patch_kind(&self) -> PatchKind

Returns bits 44..=47.

pub const fn patch_id(&self) -> u16

Returns bits 48..=63.

pub const fn set_offset(&mut self, bits: u16)

Sets bits 0..=15.

pub const fn checked_set_offset( &mut self, bits: u16, ) -> Result<(), &'static str>

Sets bits 0..=15. Returns an error if the value is too big to fit within the field bits.

pub const fn set_encoding(&mut self, bits: RelocationEncoding)

Sets bits 16..=22.

pub const fn checked_set_encoding( &mut self, bits: RelocationEncoding, ) -> Result<(), &'static str>

Sets bits 16..=22. Returns an error if the value is too big to fit within the field bits.

pub const fn set_relative(&mut self, bits: bool)

Sets bit 23.

pub const fn checked_set_relative( &mut self, bits: bool, ) -> Result<(), &'static str>

Sets bit 23. Returns an error if the value is too big to fit within the field bit.

pub const fn set_size(&mut self, bits: u8)

Sets bits 24..=31.

pub const fn checked_set_size(&mut self, bits: u8) -> Result<(), &'static str>

Sets bits 24..=31. Returns an error if the value is too big to fit within the field bits.

pub const fn set_addend(&mut self, bits: i16)

Sets bits 32..=43.

pub const fn checked_set_addend( &mut self, bits: i16, ) -> Result<(), &'static str>

Sets bits 32..=43. Returns an error if the value is too big to fit within the field bits.

pub const fn set_patch_kind(&mut self, bits: PatchKind)

Sets bits 44..=47.

pub const fn checked_set_patch_kind( &mut self, bits: PatchKind, ) -> Result<(), &'static str>

Sets bits 44..=47. Returns an error if the value is too big to fit within the field bits.

pub const fn set_patch_id(&mut self, bits: u16)

Sets bits 48..=63.

pub const fn checked_set_patch_id( &mut self, bits: u16, ) -> Result<(), &'static str>

Sets bits 48..=63. Returns an error if the value is too big to fit within the field bits.

pub fn set_bits(&mut self, bits: u64)

Sets the writable bits of the bitfield.

pub fn set_bits_with_defaults(&mut self, bits: u64)

Sets the writable bits of the bitfield while respecting defaults.

pub fn clear_bits(&mut self)

Clears the writable bits of the bitfield.

pub fn clear_bits_with_defaults(&mut self)

Clears the writable bits of the bitfield.

Source

impl Relocation

pub fn is_invalid(&self) -> bool

pub fn patch_info(&self) -> Option<PatchInfo>

pub fn supports_value(&self, value: usize) -> bool

pub fn apply_raw(&self, dest: &mut [u8], value: usize)